<?xml version="1.0" encoding="UTF-8"?>
<xsl:stylesheet xmlns:xsl="http://www.w3.org/1999/XSL/Transform"
    version="1.0">
    <xsl:template match="/">
        <html>
            <head>
                <title>Dresden Files - <xsl:value-of select="/character/name/text()"/></title>
                <style type="text/css">
                    /* Doing fonts as depicted below allows all browsers to enlarge or reduce fonts
                       per the user's choice.*/
                    body 
                    {
                    font-size:100%;  /* default font size is 16 pixels */
                    font-family:Optima,sans-serif;
                    } 
                    p {font-size:0.75em;} /* default font size is 12 pixels */
                    h6 {font-size:0.75em;} /* default font size is 12 pixels */
                    h5 {font-size:1em;} /* default font size is 16 pixels */
                    h4 {font-size:1.25em;} /* default font size is 20 pixels */
                    h3 {font-size:1.5em;} /* default font size is 24 pixels */
                    h2 {font-size:1.75em;} /* default font size is 28 pixels */
                    h1 {font-size:2em;} /* default font size is 32 pixels */
                    #nonborderblock
                    {
                    font-family:Optima,sans-serif;
                    }
                    #dblock
                    {
                    font-family:Optima,sans-serif;
                    width:100%;
                    border-collapse:collapse;
                    }
                    #dblock td,#dblock th
                    {
                    font-size:0.75em; /* provides 12pixel font. */
                    border:1px solid #000000;
                    padding:3px 7px 2px 7px;
                    }
                    #dblock th
                    {
                    font-size:1em;
                    text-align:left;
                    padding-top:5px;
                    padding-bottom:4px;
                    background-color:#AAAAAA;
                    color:#ffffff;
                    }
                    #dblock tr.alt td
                    {
                    color:#000000;
                    background-color:#DDDDDD;
                    }
                </style>
            </head>
            <body>
                <!-- Borderless table with 2 columns used to format the entire page. -->
                <table border="0">
                    <tr>
                        <!-- Following cell to contain column 1. -->
                        <td valign="top" width="50%">
                            <!-- Borderless zone containing Player name, character, occupation. -->
                            <table id="nonborderblock" border="0">
                                <tr>
                                    <td align="right"><strong>Player Name</strong></td>
                                    <td><xsl:value-of select="/character/datablock[@name='Description']/data[@name='Player Name']/text()"/></td>
                                </tr>
                                <tr>
                                    <td align="right"><strong>Character</strong></td>
                                    <td><xsl:value-of select="/character/name/text()"/></td>
                                </tr>
                                <tr>
                                    <td align="right"><strong>Template</strong></td>
                                        <xsl:for-each select="/character/datablock[@name='Template']/data">
                                            <td>
                                                <xsl:choose>
                                                   <xsl:when test="@renamed !=''">
                                                       <xsl:value-of select="@renamed"/>
                                                   </xsl:when>
                                                   <xsl:when test="text() !=''">
                                                       <xsl:value-of select="text()"/>
                                                   </xsl:when>
                                                </xsl:choose>
                                            </td>
                                        </xsl:for-each>
                                </tr>
                                <tr>
                                    <td align="right"><strong>Power Level</strong></td>
                                    <td><xsl:value-of select="/character/datablock[@name='Description']/data[@name='Power Level']/text()"/></td>
                                </tr>
                                <tr>
                                    <td align="right"><strong>Skill Cap</strong></td>
                                    <td><xsl:value-of select="/character/datablock[@name='Description']/data[@name='Skill Cap']/text()"/></td>
                                </tr>
                                <tr>
                                    <td align="right"><strong>Skill Points Available</strong></td>
                                    <td><xsl:value-of select="/character/datablock[@name='Description']/data[@name='Skill Points Available']/text()"/></td>
                                </tr>
                            </table>
                            <!-- Aspects Table -->
                            <table id="dblock">
                                <tr>
                                    <th colspan="2">Aspects</th>
                                </tr>
                                <tr><td>
                                    <xsl:for-each select="/character/datablock[@name='Aspects']/data">
                                       <!-- Aspects can be renamed by the user. -->
                                        <xsl:choose>
                                            <xsl:when test="@renamed = 'High Concept'">
                                                <strong>High Concept: </strong><xsl:value-of select="text()"/><br />
                                            </xsl:when>
                                            <xsl:when test="@renamed = 'Trouble'">
                                                <strong>Trouble: </strong><xsl:value-of select="text()"/><br />
                                            </xsl:when>
                                            <xsl:otherwise>
                                                <xsl:value-of select="@renamed"/> <em><xsl:value-of select="text()"/>; </em>
                                            </xsl:otherwise>
                                            <!-- <xsl:otherwise>
                                                <xsl:choose>
                                                    <xsl:when test="text()=''"> [This test always fails. :( Why?] 
                                                        <xsl:value-of select="@renamed"/>
                                                    </xsl:when>
                                                    <xsl:otherwise>
                                                        <xsl:value-of select="@renamed"/> <em><xsl:value-of select="text()"/>; </em>
                                                    </xsl:otherwise>
                                                </xsl:choose>
                                            </xsl:otherwise> -->
                                        </xsl:choose>
                                    </xsl:for-each>
                                </td></tr>
                            </table>
                            <p></p>
                            <table id="dblock">
                                <tr>
                                    <td align="right"><strong>Physical Stress/Taken</strong></td>
                                    <td><xsl:value-of select="/character/datablock[@name='Description']/data[@name='Physical Stress']/text()"/>
                                        <xsl:if test="/character/datablock[@name='Description']/data[@name='Phys Stress Taken']/text() != ''">
                                            / <xsl:value-of select="/character/datablock[@name='Description']/data[@name='Phys Stress Taken']/text()"/>
                                        </xsl:if>
                                    </td>
                                </tr>
                                <xsl:if test="/character/datablock[@name='Description']/data[@name='Extra Physical Cons']/text() != ''">
                                    <tr>
                                        <td align="right"><em>Extra Physical Cons</em></td>
                                        <td><xsl:value-of select="/character/datablock[@name='Description']/data[@name='Extra Physical Cons']/text()"/></td>
                                    </tr>
                                </xsl:if>
                                <tr>
                                    <td align="right"><strong>Mental Stress/Taken</strong></td>
                                    <td><xsl:value-of select="/character/datablock[@name='Description']/data[@name='Mental Stress']/text()"/>
                                        <xsl:if test="/character/datablock[@name='Description']/data[@name='Men Stress Taken']/text() != ''">
                                            / <xsl:value-of select="/character/datablock[@name='Description']/data[@name='Men Stress Taken']/text()"/>
                                        </xsl:if>
                                    </td>
                                </tr>
                                <xsl:if test="/character/datablock[@name='Description']/data[@name='Extra Mental Cons']/text() != ''">
                                    <tr>
                                        <td align="right"><em>Extra Mental Cons</em></td>
                                        <td><xsl:value-of select="/character/datablock[@name='Description']/data[@name='Extra Mental Cons']/text()"/></td>
                                    </tr>
                                </xsl:if>
                                <tr>
                                    <td align="right"><strong>Social Stress/Taken</strong></td>
                                    <td><xsl:value-of select="/character/datablock[@name='Description']/data[@name='Social Stress']/text()"/>
                                        <xsl:if test="/character/datablock[@name='Description']/data[@name='Soc Stress Taken']/text() != ''">
                                            / <xsl:value-of select="/character/datablock[@name='Description']/data[@name='Soc Stress Taken']/text()"/>
                                        </xsl:if>
                                    </td>
                                </tr>
                                <xsl:if test="/character/datablock[@name='Description']/data[@name='Extra Social Cons']/text() != ''">
                                    <tr>
                                        <td align="right"><em>Extra Social Cons</em></td>
                                        <td><xsl:value-of select="/character/datablock[@name='Description']/data[@name='Extra Social Cons']/text()"/></td>
                                    </tr>
                                </xsl:if>                                
                                <xsl:if test="/character/datablock[@name='Description']/data[@name='Armor']/text() != ''">
                                    <tr>
                                        <td align="right"><strong>Armor</strong></td>
                                        <td><xsl:value-of select="/character/datablock[@name='Description']/data[@name='Armor']/text()"/></td>
                                    </tr>
                                </xsl:if>
                                <tr>
                                    <td align="right"><strong>Base Refresh</strong></td>
                                    <td><xsl:value-of select="/character/datablock[@name='Description']/data[@name='Base Refresh']/text()"/></td>
                                </tr>
                                <tr>
                                    <td align="right"><strong>Adjusted Refresh</strong></td>
                                    <td><xsl:value-of select="/character/datablock[@name='Description']/data[@name='Adjusted Refresh']/text()"/></td>
                                </tr>
                                <tr>
                                    <td align="right"><strong>Current Fate Points</strong></td>
                                    <td><xsl:value-of select="/character/datablock[@name='Description']/data[@name='Current Fate Points']/text()"/></td>
                                </tr>
                            </table>
                            <p></p>
                            <!-- Consequences Table. Should have rows of alternate grey/white lines. -->
                            <table id="dblock">
                                <tr>
                                    <th colspan="2">Consequences</th>
                                </tr>
                                <xsl:if test="/character/datablock[@name='Consequences']/data[@name='Minor']/text() !=''">
                                    <tr>
                                        <td align="right"><strong>Minor (-2)</strong></td>
                                        <td><xsl:value-of select="/character/datablock[@name='Consequences']/data[@name='Minor']/text()"/></td>
                                    </tr>
                                </xsl:if>
                                <xsl:if test="/character/datablock[@name='Consequences']/data[@name='Moderate']/text() != ''">
                                   <tr class="alt">
                                       <td align="right"><strong>Moderate (-4)</strong></td>
                                       <td><xsl:value-of select="/character/datablock[@name='Consequences']/data[@name='Moderate']/text()"/></td>
                                   </tr>
                                </xsl:if>
                               
                                <!-- The following refers to a "Major" Consequence. This is left over and may exist in some older character sheets. 
                                I've included it here in order to support them. -->
                                <xsl:if test="/character/datablock[@name='Consequences']/data[@name='Major']/text() != ''">
                                    <tr class="alt">
                                        <td align="right"><strong>Moderate (-4)</strong></td>
                                        <td><xsl:value-of select="/character/datablock[@name='Consequences']/data[@name='Major']/text()"/></td>
                                    </tr>
                                </xsl:if>
                                
                                <xsl:if test="/character/datablock[@name='Consequences']/data[@name='Severe']/text() != ''">
                                    <tr>
                                        <td align="right"><strong>Severe (-6)</strong></td>
                                        <td><xsl:value-of select="/character/datablock[@name='Consequences']/data[@name='Severe']/text()"/></td>
                                    </tr>
                                </xsl:if>
                                <xsl:if test="/character/datablock[@name='Consequences']/data[@name='Extreme']/text() != ''">
                                   <tr class="alt">
                                       <td align="right"><strong>Extreme (-8)</strong></td>
                                       <td><xsl:value-of select="/character/datablock[@name='Consequences']/data[@name='Extreme']/text()"/></td>
                                   </tr>
                                </xsl:if>
                            </table>
                            <p></p>
                            <!-- Skill Table. Should have rows of alternate grey/white lines. -->
                            <table id="dblock">
                                <tr>
                                    <th colspan="2">Skills</th>
                                </tr>
                                <xsl:if test="/character/datablock[@name='Skills']/data[@name='Legendary (+8)']/text() != ''">
                                    <tr>
                                        <td align="right"><strong>Legendary (+8)</strong></td>
                                        <td><xsl:value-of select="/character/datablock[@name='Skills']/data[@name='Legendary (+8)']/text()"/></td>
                                    </tr>
                                </xsl:if>
                                <xsl:if test="/character/datablock[@name='Skills']/data[@name='Epic (+7)']/text() != ''">
                                   <tr class="alt">
                                       <td align="right"><strong>Epic (+7)</strong></td>
                                       <td><xsl:value-of select="/character/datablock[@name='Skills']/data[@name='Epic (+7)']/text()"/></td>
                                   </tr>
                                </xsl:if>
                                <xsl:if test="/character/datablock[@name='Skills']/data[@name='Fantastic (+6)']/text() != ''">
                                    <tr>
                                        <td align="right"><strong>Fantastic (+6)</strong></td>
                                        <td><xsl:value-of select="/character/datablock[@name='Skills']/data[@name='Fantastic (+6)']/text()"/></td>
                                    </tr>
                                </xsl:if>
                                <xsl:if test="/character/datablock[@name='Skills']/data[@name='Superb (+5)']/text() != ''">
                                   <tr class="alt">
                                       <td align="right"><strong>Superb (+5)</strong></td>
                                       <td><xsl:value-of select="/character/datablock[@name='Skills']/data[@name='Superb (+5)']/text()"/></td>
                                   </tr>
                                </xsl:if>
                                <xsl:if test="/character/datablock[@name='Skills']/data[@name='Great (+4)']/text() != ''">
                                    <tr>
                                        <td align="right"><strong>Great (+4)</strong></td>
                                        <td><xsl:value-of select="/character/datablock[@name='Skills']/data[@name='Great (+4)']/text()"/></td>
                                    </tr>
                                </xsl:if>
                                <xsl:if test="/character/datablock[@name='Skills']/data[@name='Good (+3)']/text() != ''">
                                   <tr class="alt">
                                       <td align="right"><strong>Good (+3)</strong></td>
                                       <td><xsl:value-of select="/character/datablock[@name='Skills']/data[@name='Good (+3)']/text()"/></td>
                                   </tr>
                                </xsl:if>
                                <xsl:if test="/character/datablock[@name='Skills']/data[@name='Fair (+2)']/text() != ''">
                                    <tr>
                                        <td align="right"><strong>Fair (+2)</strong></td>
                                        <td><xsl:value-of select="/character/datablock[@name='Skills']/data[@name='Fair (+2)']/text()"/></td>
                                    </tr>
                                </xsl:if>
                                <xsl:if test="/character/datablock[@name='Skills']/data[@name='Average (+1)']/text() != ''">
                                   <tr class="alt">
                                       <td align="right"><strong>Average (+1)</strong></td>
                                       <td><xsl:value-of select="/character/datablock[@name='Skills']/data[@name='Average (+1)']/text()"/></td>
                                   </tr>
                                </xsl:if>
                            </table>
                            <p></p>
                            <!-- Equipment Table -->
                            <table id="dblock">
                                <tr>
                                    <th>Equipment</th>
                                    <th>Description</th>
                                </tr>
                                <xsl:for-each select="/character/datablock[@name='Equipment']/data">
                                    <tr>
                                        <xsl:choose>
                                            <xsl:when test="@renamed !='Equipment'">
                                                <!-- Equipment can be renamed by the user. -->
                                                 <xsl:choose>
                                                     <xsl:when test="@renamed != ''">
                                                         <td><xsl:value-of select="@renamed"/></td>
                                                     </xsl:when>
                                                     <xsl:otherwise>
                                                         <td><xsl:value-of select="@name"/></td>
                                                     </xsl:otherwise>
                                                 </xsl:choose>
                                                 <td><em><xsl:value-of select="text()"/></em></td>
                                            </xsl:when>
                                        </xsl:choose>
                                    </tr>
                                </xsl:for-each>
                            </table>
                        </td>
                        
                        <!-- Following cell to contain column 2. -->
                        <td valign="top">
                            <!-- Stunts Table -->
                            <table id="dblock">
                                <tr>
                                    <th>Stunt</th>
                                    <th>Description</th>
                                </tr>
                                <xsl:for-each select="/character/datablock[@name='Stunts']/data">
                                    <tr>
                                        <!-- Stunts can be renamed by the user. -->
                                        <xsl:choose>
                                            <xsl:when test="@renamed !='Stunt'">
                                                <xsl:choose>
                                                    <xsl:when test="@renamed != ''">
                                                        <td><xsl:value-of select="@renamed"/></td>
                                                    </xsl:when>
                                                    <xsl:otherwise>
                                                        <td><xsl:value-of select="@name"/></td>
                                                    </xsl:otherwise>
                                                </xsl:choose>
                                                <td><em><xsl:value-of select="text()"/></em></td>
                                            </xsl:when>
                                        </xsl:choose>
                                    </tr>
                                </xsl:for-each>
                            </table>
                            <p></p>
                            <!-- Powers Table -->
                            <table id="dblock">
                                <tr>
                                    <th>Power</th>
                                    <th>Description</th>
                                </tr>
                                <xsl:for-each select="/character/datablock[@name='Powers']/data">
                                    <tr>
                                        <xsl:choose>
                                            <xsl:when test="@renamed !='Power'">
                                               <!-- Powers can be renamed by the user. -->
                                                <xsl:choose>
                                                    <xsl:when test="@renamed != ''">
                                                        <td><xsl:value-of select="@renamed"/></td>
                                                    </xsl:when>
                                                    <xsl:otherwise>
                                                        <td><xsl:value-of select="@name"/></td>
                                                    </xsl:otherwise>
                                                </xsl:choose>
                                            <td><em><xsl:value-of select="text()"/></em></td> 
                                            </xsl:when>
                                        </xsl:choose>
                                    </tr>
                                </xsl:for-each>
                            </table>
                            <p></p>
                            <!-- Other Stuff Table -->
                            <table id="dblock">
                                <tr>
                                    <th colspan="2">Specializations, Focus Items, Enchanted Items, Items of Power, Etc.</th>
                                </tr>
                                <xsl:for-each select="/character/datablock[@name='Other: Specializations, Focus Items, Enchanted Items, Etc.']/data">
                                    <tr>
                                        <xsl:choose>
                                            <xsl:when test="@renamed !='Other'">
                                                <!-- Other stuff can be renamed by the user. -->
                                                <xsl:choose>
                                                    <xsl:when test="@renamed != ''">
                                                        <td><xsl:value-of select="@renamed"/></td>
                                                    </xsl:when>
                                                    <xsl:otherwise>
                                                        <td><xsl:value-of select="@name"/></td>
                                                    </xsl:otherwise>
                                                </xsl:choose>
                                                <td><em><xsl:value-of select="text()"/></em></td>
                                            </xsl:when>
                                        </xsl:choose>
                                    </tr>
                                </xsl:for-each>
                            </table>
                        </td>
                    </tr>
                </table>
                <table border="0" align="center">
                    <tr>
                        <td><img src="portrait.png" alt="Portrait" width="100%"/></td>
                    </tr>
                </table>
                <!-- Include Journals, if available. -->
                <xsl:for-each select="//article">
                    <p> 
                        <article>
                            <span style="font-size:1.5em;"><strong><xsl:value-of select="@title"/></strong></span><br />
                            <xsl:for-each select="span">
                                <span>
                                    <xsl:attribute name="style"><xsl:value-of select="@style"/></xsl:attribute>
                                    <xsl:value-of select="text()"/>
                                    <xsl:if test="br">
                                        <br />
                                    </xsl:if>
                                </span>
                            </xsl:for-each>
                        </article>
                    </p>
                </xsl:for-each>
            </body>
        </html>
    </xsl:template>
</xsl:stylesheet>