<?xml version="1.0" encoding="UTF-8"?>
<xsl:stylesheet xmlns:xsl="http://www.w3.org/1999/XSL/Transform"
    version="1.0">
    <xsl:template match="/">
        <html>
            <head>
                <title>Fate - <xsl:value-of select="/character/name/text()"/></title>
                <style type="text/css">
                   /* Doing fonts as depicted below allows all browsers to enlarge or reduce fonts
                       per the user's choice.*/
                    body 
                    {
                    font-size:100%;  /* default font size is 16 pixels */
                    font-family:Optima,sans-serif;
                    } 
                    p {font-size:0.75em;} /* default font size is 12 pixels */
                    td {font-size:0.75em;} /* default font size is 12 pixels */
                    h6 {font-size:0.75em;} /* default font size is 12 pixels */
                    h5 {
                    font-size:1em;
                    font-weight:bold;
                    color:#990000;
                    } /* default font size is 16 pixels */
                    h4 {font-size:1.25em;} /* default font size is 20 pixels */
                    h3 {font-size:1.5em;} /* default font size is 24 pixels */
                    h2 {font-size:1.75em;} /* default font size is 28 pixels */
                    h1 {font-size:2em;} /* default font size is 32 pixels */
                    td.h1 {
                    font-size:1.5em;
                    font-weight:bold;
                    color:#990000;
                    }
                    td.h2 {
                    font-size:1em;
                    font-weight:bold;
                    color:#990000;
                    }
                    .bold {
                    font-size:1em;
                    font-weight:bold;
                    color:#990000;
                    }
               </style>
            </head>
            <body>
                <!-- Aspects -->
                <table border="0" width="100%">
                    <tr>
                        <td class="h1"><xsl:value-of select="/character/name/text()"/></td>
                    </tr>
                    <tr>
                        <td>
                            <xsl:for-each select="/character/datablock[@name='Aspects']/data">
                                <!-- Aspects can be renamed by the user. -->
                                <xsl:choose>
                                    <xsl:when test="@renamed = 'High Concept'">
                                        <span class="bold">High Concept: </span><xsl:value-of select="text()"/><br />
                                    </xsl:when>
                                    <xsl:when test="@renamed = 'Trouble'">
                                        <span class="bold">Trouble: </span><xsl:value-of select="text()"/><br />
                                    </xsl:when>
                                    <xsl:otherwise>
                                        <xsl:value-of select="@renamed"/> <em><xsl:value-of select="text()"/>; </em>
                                    </xsl:otherwise>
                                </xsl:choose>
                            </xsl:for-each>
                        </td>
                    </tr>
                    <!-- Skills -->
                    <tr>
                        <td><span class="bold">Skills</span></td>
                    </tr>
                    <tr>
                        <td>
                            <xsl:if test="/character/datablock[@name='Skills']/data[@name='Legendary (+8)']/text() != ''">
                                +8: <xsl:value-of select="/character/datablock[@name='Skills']/data[@name='Legendary (+8)']/text()"/>;  
                            </xsl:if>
                            <xsl:if test="/character/datablock[@name='Skills']/data[@name='Epic (+7)']/text() != ''">
                                +7: <xsl:value-of select="/character/datablock[@name='Skills']/data[@name='Epic (+7)']/text()"/>;  
                            </xsl:if>
                            <xsl:if test="/character/datablock[@name='Skills']/data[@name='Fantastic (+6)']/text() != ''">
                                +6: <xsl:value-of select="/character/datablock[@name='Skills']/data[@name='Fantastic (+6)']/text()"/>;  
                            </xsl:if>
                            <xsl:if test="/character/datablock[@name='Skills']/data[@name='Superb (+5)']/text() != ''">
                                +5: <xsl:value-of select="/character/datablock[@name='Skills']/data[@name='Superb (+5)']/text()"/>;  
                            </xsl:if>
                            <xsl:if test="/character/datablock[@name='Skills']/data[@name='Great (+4)']/text() != ''">
                                +4: <xsl:value-of select="/character/datablock[@name='Skills']/data[@name='Great (+4)']/text()"/>;  
                            </xsl:if>
                            <xsl:if test="/character/datablock[@name='Skills']/data[@name='Good (+3)']/text() != ''">
                                +3: <xsl:value-of select="/character/datablock[@name='Skills']/data[@name='Good (+3)']/text()"/>;  
                            </xsl:if>
                            <xsl:if test="/character/datablock[@name='Skills']/data[@name='Fair (+2)']/text() != ''">
                                +2: <xsl:value-of select="/character/datablock[@name='Skills']/data[@name='Fair (+2)']/text()"/>;  
                            </xsl:if>
                            <xsl:if test="/character/datablock[@name='Skills']/data[@name='Average (+1)']/text() != ''">
                                +1: <xsl:value-of select="/character/datablock[@name='Skills']/data[@name='Average (+1)']/text()"/>;  
                            </xsl:if>
                        </td>
                    </tr>
                    <!-- Stunts -->
                    <xsl:if test="/character/datablock[@name='Stunts']/data/@renamed !='Stunt'">
                        <tr>
                            <td><span class="bold">Stunts</span></td>
                        </tr>
                    </xsl:if>
                    <tr>
                        <td>
                            <xsl:for-each select="/character/datablock[@name='Stunts']/data">
                                <!-- Stunts can be renamed by the user. -->
                                <xsl:choose>
                                    <xsl:when test="@renamed !='Stunt'">
                                        <xsl:choose>
                                            <xsl:when test="@renamed != ''">
                                                <strong><xsl:value-of select="@renamed"/>: </strong>
                                            </xsl:when>
                                            <xsl:otherwise>
                                                <strong><xsl:value-of select="@name"/>: </strong>
                                            </xsl:otherwise>
                                        </xsl:choose>
                                        <xsl:value-of select="text()"/><br />
                                    </xsl:when>
                                </xsl:choose>
                            </xsl:for-each>
                        </td>
                    </tr>    
                    <!-- Stress -->
                    <tr>
                        <td><span class="bold">Stress</span></td>
                    </tr>
                    <tr>
                        <td><strong>Mental/Taken </strong>
                            <xsl:value-of select="/character/datablock[@name='Description']/data[@name='Mental Stress']/text()"/>
                            <xsl:if test="/character/datablock[@name='Description']/data[@name='Men Stress Taken']/text() != ''">
                                / <xsl:value-of select="/character/datablock[@name='Description']/data[@name='Men Stress Taken']/text()"/>
                            </xsl:if>
                            <xsl:if test="/character/datablock[@name='Description']/data[@name='Extra Mental Cons']/text() != ''">
                                <em> Extra Mental Cons: </em>
                                <xsl:value-of select="/character/datablock[@name='Description']/data[@name='Extra Mental Cons']/text()"/>
                            </xsl:if>
                            ; <strong>Physical/Taken </strong>
                            <xsl:value-of select="/character/datablock[@name='Description']/data[@name='Physical Stress']/text()"/>
                            <xsl:if test="/character/datablock[@name='Description']/data[@name='Phys Stress Taken']/text() != ''">
                                / <xsl:value-of select="/character/datablock[@name='Description']/data[@name='Phys Stress Taken']/text()"/>
                            </xsl:if>
                            <xsl:if test="/character/datablock[@name='Description']/data[@name='Extra Physical Cons']/text() != ''">
                                <em> Extra Physical Cons: </em>
                                <xsl:value-of select="/character/datablock[@name='Description']/data[@name='Extra Physical Cons']/text()"/>
                            </xsl:if>
                            ; <strong>Social/Taken </strong>
                            <xsl:value-of select="/character/datablock[@name='Description']/data[@name='Social Stress']/text()"/>
                            <xsl:if test="/character/datablock[@name='Description']/data[@name='Soc Stress Taken']/text() != ''">
                                / <xsl:value-of select="/character/datablock[@name='Description']/data[@name='Soc Stress Taken']/text()"/>
                            </xsl:if>
                            <xsl:if test="/character/datablock[@name='Description']/data[@name='Extra Social Cons']/text() != ''">
                                <em> Extra Social Cons: </em>
                                <xsl:value-of select="/character/datablock[@name='Description']/data[@name='Extra Social Cons']/text()"/>
                            </xsl:if>
                        </td>
                    </tr>
                    <!-- Total Refresh Cost -->
                    <xsl:if test="/character/datablock[@name='Description']/data[@name='Base Refresh']/text() !=''">
                        <tr>
                            <td><span class="bold">Base Refresh: </span><xsl:value-of select="/character/datablock[@name='Description']/data[@name='Base Refresh']/text()"/></td>
                        </tr>
                    </xsl:if>
                    <xsl:if test="/character/datablock[@name='Description']/data[@name='Adjusted Refresh']/text() !=''">
                        <tr>
                            <td><span class="bold">Adjusted Refresh: </span><xsl:value-of select="/character/datablock[@name='Description']/data[@name='Adjusted Refresh']/text()"/></td>
                        </tr>
                    </xsl:if>
                    <xsl:if test="/character/datablock[@name='Description']/data[@name='Current Fate Points']/text() !=''">
                        <tr>
                            <td><span class="bold">Current Fate Points: </span><xsl:value-of select="/character/datablock[@name='Description']/data[@name='Current Fate Points']/text()"/></td>
                        </tr>
                    </xsl:if>
                    <!-- Powers -->
                    <xsl:if test="/character/datablock[@name='Powers']/data/@renamed !='Power'">
                        <tr>
                            <td><span class="bold">Powers</span></td>
                        </tr>
                    </xsl:if>
                    
                    <tr>
                        <td>
                            <xsl:for-each select="/character/datablock[@name='Powers']/data">
                                <xsl:choose>
                                    <xsl:when test="@renamed !='Power'">
                                        <!-- Powers can be renamed by the user. -->
                                        <xsl:choose>
                                            <xsl:when test="@renamed != ''">
                                                <strong><xsl:value-of select="@renamed"/>: </strong>
                                            </xsl:when>
                                            <xsl:otherwise>
                                                <strong><xsl:value-of select="@name"/>: </strong>
                                            </xsl:otherwise>
                                        </xsl:choose>
                                        <xsl:value-of select="text()"/><br />
                                    </xsl:when>
                                </xsl:choose>
                            </xsl:for-each>
                        </td>
                    </tr>
                    
                    <xsl:if test="/character/datablock[@name='Other: Specializations, Focus Items, Enchanted Items, Etc.']/data/@renamed !='Other'">
                        <tr>
                            <td><span class="bold">Focus Items, Enchanted Items, Items of Powers, etc.</span></td>
                        </tr>
                    </xsl:if>
                    <tr>
                        <td>
                            <xsl:for-each select="/character/datablock[@name='Other: Specializations, Focus Items, Enchanted Items, Etc.']/data">
                                <xsl:choose>
                                    <xsl:when test="@renamed !='Other'">
                                        <!-- Other stuff can be renamed by the user. -->
                                        <xsl:choose>
                                            <xsl:when test="@renamed != ''">
                                                <strong><xsl:value-of select="@renamed"/>: </strong>
                                            </xsl:when>
                                            <xsl:otherwise>
                                                <strong><xsl:value-of select="@name"/>: </strong>
                                            </xsl:otherwise>
                                        </xsl:choose>
                                        <xsl:value-of select="text()"/><br />
                                    </xsl:when>
                                </xsl:choose>
                            </xsl:for-each>
                        </td>
                    </tr>
                    
                    <!-- Consequences -->
                    <tr>
                        <td>
                            <xsl:choose>
                                <xsl:when test="/character/datablock[@name='Consequences']/data[@name='Minor']/text() !=''">
                                    <span class="bold">Consequences</span><br/>
                                </xsl:when>
                                <xsl:when test="/character/datablock[@name='Consequences']/data[@name='Moderate']/text() !=''">
                                    <span class="bold">Consequences</span><br/>
                                </xsl:when>
                                <!-- The following refers to a "Major" Consequence. This is left over and may exist in some older character sheets. 
                                I've included it here in order to support them. -->
                                <xsl:when test="/character/datablock[@name='Consequences']/data[@name='Major']/text() !=''">
                                    <span class="bold">Consequences</span><br/>
                                </xsl:when>
                                <xsl:when test="/character/datablock[@name='Consequences']/data[@name='Severe']/text() !=''">
                                    <span class="bold">Consequences</span><br/>
                                </xsl:when>
                                <xsl:when test="/character/datablock[@name='Consequences']/data[@name='Extreme']/text() !=''">
                                    <span class="bold">Consequences</span><br/>
                                </xsl:when>
                            </xsl:choose>
                            
                            <xsl:if test="/character/datablock[@name='Consequences']/data[@name='Minor']/text() !=''">
                                <strong>Minor (-2) </strong><xsl:value-of select="/character/datablock[@name='Consequences']/data[@name='Minor']/text()"/><br />
                            </xsl:if>
                            <xsl:if test="/character/datablock[@name='Consequences']/data[@name='Moderate']/text() != ''">
                                <strong>Moderate (-4) </strong><xsl:value-of select="/character/datablock[@name='Consequences']/data[@name='Moderate']/text()"/><br />
                            </xsl:if>
                            <!-- The following refers to a "Major" Consequence. This is left over and may exist in some older character sheets. 
                                I've included it here in order to support them. -->
                            <xsl:if test="/character/datablock[@name='Consequences']/data[@name='Major']/text() != ''">
                                <strong>Moderate (-4) </strong><xsl:value-of select="/character/datablock[@name='Consequences']/data[@name='Major']/text()"/><br />
                            </xsl:if>
                            <xsl:if test="/character/datablock[@name='Consequences']/data[@name='Severe']/text() != ''">
                                <strong>Severe (-6) </strong><xsl:value-of select="/character/datablock[@name='Consequences']/data[@name='Severe']/text()"/><br />
                            </xsl:if>
                            <xsl:if test="/character/datablock[@name='Consequences']/data[@name='Extreme']/text() != ''">
                                <strong>Extreme (-8) </strong><xsl:value-of select="/character/datablock[@name='Consequences']/data[@name='Extreme']/text()"/>
                            </xsl:if>
                        </td>
                    </tr>
                    <!-- Equipment -->
                    <xsl:if test="/character/datablock[@name='Equipment']/data/@renamed !='Equipment'">
                        <tr>
                            <td><span class="bold">Equipment</span></td>
                        </tr>
                    </xsl:if>
                    <xsl:for-each select="/character/datablock[@name='Equipment']/data">
                        <xsl:if test="@renamed != 'Equipment'">
                                <!-- Equipment is named by the user and therefore always has an 
                                 entry in the renamed attribute. -->
                            <tr><td><strong><xsl:value-of select="@renamed"/>. </strong><xsl:value-of select="text()"/></td></tr>
                        </xsl:if>
                    </xsl:for-each>
                </table>
                
                <!-- Journals -->
                <xsl:for-each select="//article">
                    <p> 
                        <article>
                            <xsl:attribute name="title"><xsl:value-of select="@title"/></xsl:attribute>
                            <span style="font-size:1em;font-weight:bold;color:#990000;"><xsl:value-of select="@title"/></span><br />
                            <xsl:for-each select="span">
                                <span>
                                    <xsl:attribute name="style"><xsl:value-of select="@style"/></xsl:attribute>
                                    <xsl:value-of select="text()"/>
                                    <xsl:if test="br">
                                        <br />
                                    </xsl:if>
                                </span>
                            </xsl:for-each>
                        </article>
                    </p>
                </xsl:for-each>
            </body>
        </html>
    </xsl:template>
</xsl:stylesheet>